<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Nível %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Sem Capa</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Done</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Introduza a nova extensão:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Criar Nova Extensão</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Directoria que contém os filmes</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Esta directoria tem de existir e o utilizador que corre o MythVideo tem de ter permissões para a ler.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Nível de Acesso Inicial</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 -  Restricto</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Permissivo</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation>Este é o nível de acesso que o MythVideo usa quando é iniciado. Todos os filmes com um nível igual ou inferior serão mostrados na lista ou serão navegáveis por omissão. O código de acesso deverá ser preenchido para permitir a mudança do nível por omissão.</translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>Cõdigo de Acesso</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation>Se activar, só conseguirá aceder às configurações se introduzir o Código de Acesso. Cuidado.</translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Mostrar Ficheiros de Tipo Desconhecido</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>Se estiver activo, todos os ficheiros na directoria configurada serão mostrados, a menos que tenham uma extensão definida explicitamente para ser ignorada.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>Lista de Filmes Mostra Ficheiros</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Se estiver activo, o ecrâ da lista de filmes mostrará todos os ficheiros relevantes dentro da directoria de filmes que esteja configurada, quer a directoria tenha já sido pesquisada ou não.</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Comando Padrão</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Configurações de Leitura</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Código de Acesso:</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Sem Capa</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation type="obsolete">Classificação Desconhecida</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Listings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Browser browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings (1/2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings (2/2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video List Loads Video Meta Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorting ignores case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, case is ignored when sorting entries in a view.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show folders for database views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, sub folders of your video directory will be shown in supported views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image cache size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting determines the number of images MythVideo will cache for views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>^(The |A |An )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Não</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Director:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Ano:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Classificação:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Nível de Acesso:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Visionável:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Duração:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Resumo:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Ficheiro:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Ficheiro de Capa:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>Chave IMDB:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>A obter a informação...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ a obter ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Chave IMDB #</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>A Carregar...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>Não foram encontrados nenhuns filmes</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Dirigido por</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Ficheiro:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <source>PL </source>
        <translation>LST </translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>Associação de Ficheiros do MythVideo</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Extensão:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Usar cliente padrão:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignorar:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Editar Informação do Filme</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Nível de Acesso:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Ficheiro para Tocar Depois:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Incluir ao Navegar:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Imagem de Capa:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Comando de Execução Especial:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/directoria/para/a/imagem.jpg</translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished">1</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Country :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 de %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Não Existem Filmes</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Não existe classificação disponível.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutos</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Código de Acesso:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconhecido</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished">minutos</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished">Ok</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation type="unfinished">Introduza Chave IMDB #</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutos</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Não</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Sem Capa</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconhecido</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Nenhum</translation>
    </message>
    <message>
        <source>NR</source>
        <translation type="obsolete">SC</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Não existe classificação disponível.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutos</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Código de Acesso:</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
